<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>AddMeta</name>
    <message>
        <source>Insert a:</source>
        <translation>Insertar:</translation>
    </message>
    <message>
        <source>&amp;Marker</source>
        <translation>&amp;Marcador</translation>
    </message>
    <message>
        <source>Log C&amp;hain</source>
        <translation>Enca&amp;denar a Lista</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Voice &amp;Track</source>
        <translation>Pista de &amp;voz</translation>
    </message>
</context>
<context>
    <name>EditChain</name>
    <message>
        <source>Edit Log Chain</source>
        <translation>Editar encadenamiento</translation>
    </message>
    <message>
        <source>Start at:</source>
        <translation type="obsolete">Inicia en:</translation>
    </message>
    <message>
        <source>Action If Previous Event Still Playing</source>
        <translation type="obsolete">Acción si el evento previo no ha terminado</translation>
    </message>
    <message>
        <source>Start Immediately</source>
        <translation type="obsolete">Iniciar de inmediato</translation>
    </message>
    <message>
        <source>Make Next</source>
        <translation type="obsolete">Convertir en el siguente</translation>
    </message>
    <message>
        <source>Wait up to</source>
        <translation type="obsolete">Espe. hasta</translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="obsolete">Reproducir</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation type="obsolete">Segue</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="obsolete">Parar</translation>
    </message>
    <message>
        <source>Transition Type:</source>
        <translation type="obsolete">Tipo de transición:</translation>
    </message>
    <message>
        <source>Log Name</source>
        <translation>Nombre de la Lista</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Seleccionar</translation>
    </message>
    <message>
        <source>Log Description</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;Aceptar</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Cancelar</translation>
    </message>
    <message>
        <source>Transition If Previous Cart Ends Before</source>
        <translation type="obsolete">Transic. si cart. previo termina antes de</translation>
    </message>
</context>
<context>
    <name>EditLog</name>
    <message>
        <source>Edit Log</source>
        <translation>Editar Lista</translation>
    </message>
    <message>
        <source>Log Name:</source>
        <translation>Nombre:</translation>
    </message>
    <message>
        <source>Origin:</source>
        <translation>Por:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Descripción:</translation>
    </message>
    <message>
        <source>Service:</source>
        <translation>Servicio:</translation>
    </message>
    <message>
        <source>Start Date:</source>
        <translation>Fecha de inicio:</translation>
    </message>
    <message>
        <source>End Date:</source>
        <translation>Fecha fin:</translation>
    </message>
    <message>
        <source>Start Date Enabled</source>
        <translation>Fecha de inicio activada</translation>
    </message>
    <message>
        <source>End Date Enabled</source>
        <translation>Fecha de fin activada</translation>
    </message>
    <message>
        <source>TIME</source>
        <translation type="obsolete">TIEMPO</translation>
    </message>
    <message>
        <source>TRANS</source>
        <translation type="obsolete">TRANS</translation>
    </message>
    <message>
        <source>CART</source>
        <translation type="obsolete">CARTUCHO</translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation type="obsolete">GRUPO</translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation type="obsolete">DURACIÓN</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation type="obsolete">TÍTULO</translation>
    </message>
    <message>
        <source>ARTIST</source>
        <translation type="obsolete">ARTISTA</translation>
    </message>
    <message>
        <source>CLIENT</source>
        <translation type="obsolete">CLIENTE</translation>
    </message>
    <message>
        <source>AGENCY</source>
        <translation type="obsolete">AGENCIA</translation>
    </message>
    <message>
        <source>LABEL</source>
        <translation type="obsolete">ETIQUETA</translation>
    </message>
    <message>
        <source>LINE ID</source>
        <translation type="obsolete">ID LÍNEA</translation>
    </message>
    <message>
        <source>COUNT</source>
        <translation type="obsolete">CUENTA</translation>
    </message>
    <message>
        <source>Insert
Cart</source>
        <translation>Insertar
Cartucho</translation>
    </message>
    <message>
        <source>Insert
Meta</source>
        <translation>Insertar
Meta</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Cortar</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Pegar</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Guardar</translation>
    </message>
    <message>
        <source>Save
&amp;As</source>
        <translation type="obsolete">Guardar
&amp;como</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Aceptar</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Invalid Carts</source>
        <translation>Cartuchos inválidos</translation>
    </message>
    <message>
        <source>This log contains one or more carts
that are invalid for the selected service!</source>
        <translation>¡Esta Lista contiene uno o más cartuchos
que son inválidos para el dispositivo elegido!</translation>
    </message>
    <message>
        <source>The log contains carts that are disabled
for the selected service!</source>
        <translation>¡La Lista contiene cartuchos que están
desactivados para el dispositivo seleccionado!</translation>
    </message>
    <message>
        <source>Add Log</source>
        <translation>Agregar Lista</translation>
    </message>
    <message>
        <source>Log Exists</source>
        <translation type="obsolete">La Lista ya existe</translation>
    </message>
    <message>
        <source>Log Already Exists!</source>
        <translation type="obsolete">¡El playlist o Lista ya existe!</translation>
    </message>
    <message>
        <source>RDLogEdit</source>
        <translation></translation>
    </message>
    <message>
        <source>The log has been modified.
Do you want to save your changes?</source>
        <translation>La Lista ha sido modificada.
¿Desea guardar los cambios?</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation>REPROD</translation>
    </message>
    <message>
        <source>STOP</source>
        <translation>PARAR</translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation>SEGUE</translation>
    </message>
    <message>
        <source>[cart not found]</source>
        <translation>[cartucho no encontrado]</translation>
    </message>
    <message>
        <source>MARKER</source>
        <translation>MARCADOR</translation>
    </message>
    <message>
        <source>LOG CHAIN</source>
        <translation>ENCADENAR A LISTA</translation>
    </message>
    <message>
        <source>--- end of log ---</source>
        <translation>--- fin de lista ---</translation>
    </message>
    <message>
        <source>SOURCE</source>
        <translation type="obsolete">FUENTE</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Traffic</source>
        <translation>Tráfico</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <source>RDLogManager</source>
        <translation>RDLogManager</translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation>PISTA</translation>
    </message>
    <message>
        <source>Voice Tracker</source>
        <translation>Pista de voz</translation>
    </message>
    <message>
        <source>Tracks:</source>
        <translation>Pistas:</translation>
    </message>
    <message>
        <source>Voice Track</source>
        <translation>Pista de voz</translation>
    </message>
    <message>
        <source>LINK</source>
        <translation>ENLACE</translation>
    </message>
    <message>
        <source>[traffic import]</source>
        <translation>[importar tráfico]</translation>
    </message>
    <message>
        <source>[music import]</source>
        <translation>[importar música]</translation>
    </message>
    <message>
        <source>The log contains carts that are disabled
for the selected service!

Do you still want to save?</source>
        <translation>¡La Lista contiene cartuchos que están 
desactivados para el servicio actual!

¿Aún así desea guardarlo?</translation>
    </message>
    <message>
        <source>[INVALID CART]</source>
        <translation>[CARTUCHO INVÁLIDO]</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Sí</translation>
    </message>
    <message>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <source>Enable AutoRefresh:</source>
        <translation>Activar AutoActualizar:</translation>
    </message>
    <message>
        <source>&amp;Reports</source>
        <translation>&amp;Reportes</translation>
    </message>
    <message>
        <source>Next Stop:</source>
        <translation>Próx.parad:</translation>
    </message>
    <message>
        <source>Log End:</source>
        <translation>Fin Lista:</translation>
    </message>
    <message>
        <source>Run Length</source>
        <translation type="unfinished">Durac. total</translation>
    </message>
    <message>
        <source>Selected:</source>
        <translation>Seleccionado:</translation>
    </message>
    <message>
        <source>Delete on</source>
        <translation>Borrar el</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Seleccionar</translation>
    </message>
    <message>
        <source>Unable to save log, audio deletion error!</source>
        <translation>No es posible guardar la Lista, ¡error por eliminación de audio!</translation>
    </message>
    <message>
        <source>Link Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Len</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished">Guardar</translation>
    </message>
    <message>
        <source>As</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Render</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User</source>
        <translation type="obsolete">Usuario</translation>
    </message>
    <message>
        <source>Log Locked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log already being edited by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Time</source>
        <translation type="unfinished">Tiempo</translation>
    </message>
    <message>
        <source>Trans</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart</source>
        <translation type="unfinished">Cartucho</translation>
    </message>
    <message>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished">Título</translation>
    </message>
    <message>
        <source>Artist</source>
        <translation type="unfinished">Artista</translation>
    </message>
    <message>
        <source>Client</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Agency</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Etiqueta</translation>
    </message>
    <message>
        <source>Source</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ext Data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Line ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Count</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scheduled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Start Times As</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sch. Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Estimated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Est. Time</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditLogLine</name>
    <message>
        <source>Edit Log Entry</source>
        <translation>Editar entrada</translation>
    </message>
    <message>
        <source>Start at:</source>
        <translation type="obsolete">Inicia en:</translation>
    </message>
    <message>
        <source>Action If Previous Event Still Playing</source>
        <translation type="obsolete">Acción si el evento previo no ha terminado</translation>
    </message>
    <message>
        <source>Start Immediately</source>
        <translation type="obsolete">Iniciar de inmediato</translation>
    </message>
    <message>
        <source>Make Next</source>
        <translation type="obsolete">Convertir en el siguente</translation>
    </message>
    <message>
        <source>Wait up to</source>
        <translation type="obsolete">Esp. hasta</translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="obsolete">Reproducir</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation type="obsolete">Segue</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="obsolete">Parar</translation>
    </message>
    <message>
        <source>Transition Type:</source>
        <translation type="obsolete">Tipo de transición:</translation>
    </message>
    <message>
        <source>Cart</source>
        <translation>Cartucho</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <source>Artist</source>
        <translation>Artista</translation>
    </message>
    <message>
        <source>Select
Cart</source>
        <translation>Seleccionar
cartucho</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;Aceptar</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Cancelar</translation>
    </message>
    <message>
        <source>Transition If Previous Cart Ends Before</source>
        <translation type="obsolete">Transic. si cart. previo termina antes de</translation>
    </message>
    <message>
        <source>Missing Cart</source>
        <translation>Cartucho no encontrado</translation>
    </message>
    <message>
        <source>You must supply a cart number!</source>
        <translation>¡Debe introducir un número de cartucho!</translation>
    </message>
    <message>
        <source>Disabled Cart</source>
        <translation>Cartucho desactivado</translation>
    </message>
    <message>
        <source>This cart belongs to a disabled
group for the specified service!</source>
        <translation>¡Este cartucho pertenece a un grupo que está 
desactivado para el servicio especificado!</translation>
    </message>
    <message>
        <source>No Fade on Segue Out</source>
        <translation>Sin &quot;fade&quot; en un segue de salida</translation>
    </message>
    <message>
        <source>Duplicate Start Time</source>
        <translation type="obsolete">Tiempo de inicio duplicado</translation>
    </message>
    <message>
        <source>An event is already scheduled with this start time!</source>
        <translation type="obsolete">¡Se programó un evento para esta misma hora de inicio!</translation>
    </message>
</context>
<context>
    <name>EditMarker</name>
    <message>
        <source>Edit Log Marker</source>
        <translation>Editar marcador</translation>
    </message>
    <message>
        <source>Start at:</source>
        <translation type="obsolete">Inicia en:</translation>
    </message>
    <message>
        <source>Action If Previous Event Still Playing</source>
        <translation type="obsolete">Acción si el evento previo no ha terminado</translation>
    </message>
    <message>
        <source>Start Immediately</source>
        <translation type="obsolete">Iniciar de inmediato</translation>
    </message>
    <message>
        <source>Make Next</source>
        <translation type="obsolete">Convertir en el siguente</translation>
    </message>
    <message>
        <source>Wait up to</source>
        <translation type="obsolete">Esp. hasta</translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="obsolete">Reproducir</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation type="obsolete">Segue</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="obsolete">Parar</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Comentario</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;Aceptar</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Cancelar</translation>
    </message>
    <message>
        <source>Transition If Previous Cart Ends Before</source>
        <translation type="obsolete">Transic. si cart. previo termina antes de</translation>
    </message>
    <message>
        <source>Transition Type:</source>
        <translation type="obsolete">Tipo de transición:</translation>
    </message>
</context>
<context>
    <name>EditTrack</name>
    <message>
        <source>Edit Voice Track Marker</source>
        <translation>Editar marcador de Voicetrack</translation>
    </message>
    <message>
        <source>Start at:</source>
        <translation type="obsolete">Inicia en:</translation>
    </message>
    <message>
        <source>Action If Previous Event Still Playing</source>
        <translation type="obsolete">Acción si el evento previo no ha terminado</translation>
    </message>
    <message>
        <source>Start Immediately</source>
        <translation type="obsolete">Iniciar de inmediato</translation>
    </message>
    <message>
        <source>Make Next</source>
        <translation type="obsolete">Convertir en el siguente</translation>
    </message>
    <message>
        <source>Wait up to</source>
        <translation type="obsolete">Esp. hasta</translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="obsolete">Reproducir</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation type="obsolete">Segue</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="obsolete">Parar</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Comentario</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;Aceptar</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Cancelar</translation>
    </message>
    <message>
        <source>Transition If Previous Cart Ends Before</source>
        <translation type="obsolete">Transic. si cart. previo termina antes de</translation>
    </message>
    <message>
        <source>Transition Type:</source>
        <translation type="obsolete">Tipo de transición:</translation>
    </message>
</context>
<context>
    <name>ListLogs</name>
    <message>
        <source>Select a Log</source>
        <translation type="obsolete">Seleccione una Lista</translation>
    </message>
    <message>
        <source>NAME</source>
        <translation type="obsolete">NOMBRE</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation type="obsolete">DESCRIPCIÓN</translation>
    </message>
    <message>
        <source>SERVICE</source>
        <translation type="obsolete">SERVICIO</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;Aceptar</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Cancelar</translation>
    </message>
</context>
<context>
    <name>ListReports</name>
    <message>
        <source>RDLibrary Reports</source>
        <translation type="obsolete">Reportes de RDLibrary</translation>
    </message>
    <message>
        <source>Log Listing</source>
        <translation>Listas de reproducción</translation>
    </message>
    <message>
        <source>Log Exception Report</source>
        <translation>Reporte de Excepciones</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>&amp;Generate</source>
        <translation>&amp;Generar</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <source>Log Check</source>
        <translation>Chequear Listas</translation>
    </message>
    <message>
        <source>No exceptions found.</source>
        <translation>No se encontraron excepciones.</translation>
    </message>
    <message>
        <source>[none]</source>
        <translation>[ninguno]</translation>
    </message>
    <message>
        <source>Effective Date:</source>
        <translation>Fecha efectiva:</translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation>&amp;Seleccionar</translation>
    </message>
    <message>
        <source>Reports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log Listing (CSV)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Traffic Import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Music Import</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>RDLogEdit - Host</source>
        <translation type="obsolete">RDLogEdit - Computador </translation>
    </message>
    <message>
        <source>User: [Unknown]</source>
        <translation type="obsolete">Usuario: [Desconocido]</translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation type="obsolete">No puedo conectarme</translation>
    </message>
    <message>
        <source>LOG NAME</source>
        <translation type="obsolete">NOMBRE DE LA LISTA</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation type="obsolete">DESCRIPCIÓN</translation>
    </message>
    <message>
        <source>SERVICE</source>
        <translation type="obsolete">SERVICIO</translation>
    </message>
    <message>
        <source>VALID FROM</source>
        <translation type="obsolete">VÁLIDO DESDE</translation>
    </message>
    <message>
        <source>VALID TO</source>
        <translation type="obsolete">VÁLIDO HASTA</translation>
    </message>
    <message>
        <source>ORIGIN</source>
        <translation type="obsolete">ORIGEN</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Añadir</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Borrar</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Usuario</translation>
    </message>
    <message>
        <source>Add Log</source>
        <translation>Agregar lista</translation>
    </message>
    <message>
        <source>Log Exists</source>
        <translation type="obsolete">La Lista ya existe</translation>
    </message>
    <message>
        <source>Log Already Exists!</source>
        <translation type="obsolete">¡La lista de reproducción ya existe!</translation>
    </message>
    <message>
        <source>Always</source>
        <translation>Siempre</translation>
    </message>
    <message>
        <source>TFN</source>
        <translation></translation>
    </message>
    <message>
        <source>This will also delete the</source>
        <translation>Esto también borrará los </translation>
    </message>
    <message>
        <source>voice tracks associated with this log.
Continue?</source>
        <translation type="obsolete"> voicetracks asociados a esta lista.
¿Desea continuar?</translation>
    </message>
    <message>
        <source>Tracks Exist</source>
        <translation>La pista ya existe</translation>
    </message>
    <message>
        <source>TRACKS</source>
        <translation type="obsolete">PISTAS</translation>
    </message>
    <message>
        <source>Voice
&amp;Tracker</source>
        <translation>Pistas
de &amp;Voz</translation>
    </message>
    <message>
        <source>Delete Log</source>
        <translation>Eliminar Lista</translation>
    </message>
    <message>
        <source>MUSIC</source>
        <translation type="obsolete">MÚSICA</translation>
    </message>
    <message>
        <source>TRAFFIC</source>
        <translation type="obsolete">TRÁFICO</translation>
    </message>
    <message>
        <source>LAST LINKED</source>
        <translation type="obsolete">ÚLTIMO ENLACE</translation>
    </message>
    <message>
        <source>LAST MODIFIED</source>
        <translation type="obsolete">ÚLTIMO CAMBIO</translation>
    </message>
    <message>
        <source>AUTO REFRESH</source>
        <translation type="obsolete">AUTO ACTUALIZAR</translation>
    </message>
    <message>
        <source>Log
Report</source>
        <translation>Reporte
de Listas</translation>
    </message>
    <message>
        <source>Unable to delete log, audio deletion error!</source>
        <translation type="obsolete">¡No es posible eliminar la lista, error de eliminación de audios!</translation>
    </message>
    <message>
        <source>RDLogEdit -- Database Skew</source>
        <translation type="obsolete">RDLogEdit -- Asimetría en la Base de Datos</translation>
    </message>
    <message>
        <source>This version of RDLogEdit is incompatible with the version installed on the server.
See your system administrator for an update!</source>
        <translation type="obsolete">Esta versión de RDLogEdit es incompatible con la versión instalada en el servidor.
¡Solicite una actualización al administrador!</translation>
    </message>
    <message>
        <source>Host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete the</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>log?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>voice tracks associated with this log.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continue?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete these</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>logs?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>voice tracks associated with these logs.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to delete log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>audio deletion error!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>is in use by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown command option</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log Name</source>
        <translation type="unfinished">Nombre de la Lista</translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished">Música</translation>
    </message>
    <message>
        <source>Traffic</source>
        <translation type="unfinished">Tráfico</translation>
    </message>
    <message>
        <source>Tracks</source>
        <translation type="unfinished">Pistas</translation>
    </message>
    <message>
        <source>Valid From</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Valid To</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto Refresh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Origin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last Linked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last Modified</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenderDialog</name>
    <message>
        <source>Render Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rendering Log...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Render Progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart/Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Render To</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select</source>
        <translation type="unfinished">Seleccionar</translation>
    </message>
    <message>
        <source>Audio Parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[now]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>As Specified</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Virtual Start Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Events</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Only Selected Events</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Include</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop Rendering</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Treat as PLAY</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>At STOP transition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Render</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Cancelar</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rendering Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VoiceTracker</name>
    <message>
        <source>Voice Tracker</source>
        <translation>Pista de voz</translation>
    </message>
    <message>
        <source>Edit Cue Markers</source>
        <translation>Editar marcadores</translation>
    </message>
    <message>
        <source>Undo Segue Changes</source>
        <translation>Deshacer cambios en Segue</translation>
    </message>
    <message>
        <source>Set Start Point Here</source>
        <translation>Colocar punto de inicio aquí</translation>
    </message>
    <message>
        <source>Set End Point Here</source>
        <translation>Colocar punto de fin aquí</translation>
    </message>
    <message>
        <source>Set to Hook Markers</source>
        <translation>Colocar en los marcadores &quot;Hook&quot;</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Inicio</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Grabar</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>&amp;Previous
Track</source>
        <translation>Pista 
&amp;Anterior</translation>
    </message>
    <message>
        <source>&amp;Next
Track</source>
        <translation>Pista
&amp;Siguiente</translation>
    </message>
    <message>
        <source>Remaining</source>
        <translation>Restan</translation>
    </message>
    <message>
        <source>Tracks</source>
        <translation>Pistas</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Tiempo</translation>
    </message>
    <message>
        <source> </source>
        <translation> </translation>
    </message>
    <message>
        <source>TIME</source>
        <translation type="obsolete">TIEMPO</translation>
    </message>
    <message>
        <source>TRANS</source>
        <translation type="obsolete">TRANS</translation>
    </message>
    <message>
        <source>CART</source>
        <translation type="obsolete">CARTUCHO</translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation type="obsolete">GRUPO</translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation type="obsolete">DURACIÓN</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation type="obsolete">TÍTULO</translation>
    </message>
    <message>
        <source>ARTIST</source>
        <translation type="obsolete">ARTISTA</translation>
    </message>
    <message>
        <source>Do Over</source>
        <translation>Sobre-
escribir</translation>
    </message>
    <message>
        <source>Hit Post</source>
        <translation></translation>
    </message>
    <message>
        <source>Insert
Track</source>
        <translation>Insertar
Pista</translation>
    </message>
    <message>
        <source>Delete
Track</source>
        <translation>Borrar
Pista</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <source>No VoiceTrack Group</source>
        <translation>No hay grupos para las pistas de voz</translation>
    </message>
    <message>
        <source>No voicetracking group has been defined for this service,
therefore only existing transitions will be editable.</source>
        <translation>No se ha definido un grupo para las pistas de voz, por ende
sólo podrás editar transiciones ya existentes.</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importar</translation>
    </message>
    <message>
        <source>Cart Creation Failure</source>
        <translation>Falló la creación de cartuchos</translation>
    </message>
    <message>
        <source>Unable to create new cart for voice track!</source>
        <translation>¡No fue posible crear un nuevo cartucho para la pista de voz!</translation>
    </message>
    <message>
        <source>RDLogEdit</source>
        <translation>RDLogEdit</translation>
    </message>
    <message>
        <source>Audio Deletion Error!</source>
        <translation>¡Error eliminando audio!</translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation>PISTA</translation>
    </message>
    <message>
        <source>Voice Track</source>
        <translation>Pista de voz</translation>
    </message>
    <message>
        <source>Track List</source>
        <translation>Listado de pistas</translation>
    </message>
    <message>
        <source>No more tracks!</source>
        <translation>¡No hay más pistas!</translation>
    </message>
    <message>
        <source>[end of log]</source>
        <translation>[fin de la lista]</translation>
    </message>
    <message>
        <source>[cart not found]</source>
        <translation>[cartucho no encontrado]</translation>
    </message>
    <message>
        <source>MARKER</source>
        <translation>MARCADOR</translation>
    </message>
    <message>
        <source>LOG CHAIN</source>
        <translation>ENCADENAR A LISTA</translation>
    </message>
    <message>
        <source>LINK</source>
        <translation>ENLACE</translation>
    </message>
    <message>
        <source>[music import]</source>
        <translation>[importar música]</translation>
    </message>
    <message>
        <source>[traffic import]</source>
        <translation>[importar tráfico]</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation>REPROD</translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation>SEGUE</translation>
    </message>
    <message>
        <source>STOP</source>
        <translation>PARAR</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Abortar</translation>
    </message>
    <message>
        <source>Segue Changed</source>
        <translation>Segue modificado</translation>
    </message>
    <message>
        <source>Save segue changes?</source>
        <translation>¿Guardar cambios en Segue?</translation>
    </message>
    <message>
        <source>RDLogEdit - Voice Tracker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This cart cannot contain any additional cuts!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LABEL</source>
        <translation type="obsolete">ETIQUETA</translation>
    </message>
    <message>
        <source>Log Locked</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log already being edited by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Talk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trans</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cart</source>
        <translation type="unfinished">Cartucho</translation>
    </message>
    <message>
        <source>Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished">Título</translation>
    </message>
    <message>
        <source>Artist</source>
        <translation type="unfinished">Artista</translation>
    </message>
    <message>
        <source>Album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Etiqueta</translation>
    </message>
</context>
</TS>
